@@ -1,4 +1,5 @@
 import json
+from logging import Logger
 from dataclasses import dataclass
 from typing import Tuple, Optional, Dict
 
@@ -58,23 +59,23 @@ class StealthConfig:
         ```
     """
     # scripts
-    webdrive: bool = True
+    webdrive: bool = False
     webgl_vendor: bool = True
-    navigator_vendor: bool = True
+    navigator_vendor: bool = False
     navigator_plugins: bool = False
-    navigator_permissions: bool = True
-    navigator_languages: bool = True
+    navigator_permissions: bool = False
+    navigator_languages: bool = False
     navigator_platform: bool = True
     navigator_user_agent: bool = False
     navigator_hardware_concurrency: int = -1
     media_codecs: bool = True
-    iframe_content_window: bool = True
+    iframe_content_window: bool = False
     chrome_runtime: bool = False
     chrome_loadtimes: bool = False
     chrome_csi: bool = False
     chrome_app: bool = False
     dimensions: bool = True
-    hairline: bool = True
+    hairline: bool = False
     screen_touch: bool = True
 
     # options
@@ -103,7 +104,7 @@ class StealthConfig:
         # init utils and magic-arrays helper
         yield SCRIPTS['utils']
         yield SCRIPTS['magic-arrays']
-        yield SCRIPTS['navigator_hardware_concurrency']
+        # yield SCRIPTS['navigator_hardware_concurrency']
 
         if self.webdrive:
             yield SCRIPTS['webdrive']
@@ -147,7 +148,7 @@ def stealth_sync(page: SyncPage, config: StealthConfig = None):
         page.add_init_script(script)
 
 
-async def stealth_async(page: AsyncPage, config: StealthConfig = None):
+async def stealth_async(page: AsyncPage, logger: Logger):
     """teaches asynchronous playwright Page to be stealthy like a ninja!"""
-    for script in (config or StealthConfig()).enabled_scripts:
+    for script in (StealthConfig()).enabled_scripts:
         await page.add_init_script(script)
